An S4 class to represent numeric vectors that are mostly zero.

Slots

value

Numeric vector of non-zero values.

pos

Integer vector of positions corresponding to value.

length

Integer scalar specifying the total length of the vector.