sparse_numeric-class.RdAn S4 class to represent numeric vectors that are mostly zero.
valueNumeric vector of non-zero values.
posInteger vector of positions corresponding to value.
lengthInteger scalar specifying the total length of the vector.